# Auth0 AI SDK

`auth0-ai` is an SDK for building secure AI-powered applications using [Auth0](https://www.auth0.ai/).

This SDK provides base abstractions for authentication and authorization in AI applications including a set of tools for implementing [asynchronous authorization](https://auth0.com/ai/docs/intro/asynchronous-authorization) using the [Client Initiated Backchannel Authentication (CIBA)](https://openid.net/specs/openid-client-initiated-backchannel-authentication-core-1_0.html) protocol.

![Release](https://img.shields.io/pypi/v/auth0-ai) ![Downloads](https://img.shields.io/pypi/dw/auth0-ai) [![License](https://img.shields.io/:license-APACHE%202.0-blue.svg?style=flat)](https://opensource.org/license/apache-2-0)

## Installation

> ⚠️ **WARNING**: `auth0-ai` is currently under development and it is not intended to be used in production, and therefore has no official support.

```bash
pip install auth0-ai
```

---

<p align="center">
  <picture>
    <source media="(prefers-color-scheme: light)" srcset="https://cdn.auth0.com/website/sdks/logos/auth0_light_mode.png"   width="150">
    <source media="(prefers-color-scheme: dark)" srcset="https://cdn.auth0.com/website/sdks/logos/auth0_dark_mode.png" width="150">
    <img alt="Auth0 Logo" src="https://cdn.auth0.com/website/sdks/logos/auth0_light_mode.png" width="150">
  </picture>
</p>
<p align="center">Auth0 is an easy to implement, adaptable authentication and authorization platform. To learn more checkout <a href="https://auth0.com/why-auth0">Why Auth0?</a></p>
<p align="center">
This project is licensed under the Apache 2.0 license. See the <a href="https://github.com/auth0-lab/auth0-ai-python/blob/main/LICENSE"> LICENSE</a> file for more info.</p>
